@@ -23,7 +23,7 @@
 #ifndef XRB_FEEDBACK_H
 #define XRB_FEEDBACK_H
 
-#ifndef XRB_NO_XOSD
+#ifdef HAVE_XOSD
 #include "xosd.h"
 extern xosd *osd;
 #endif
